@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11877 2020-01-19 07:42:51Z Trista $
+# $Id: __init__.py 11904 2020-02-05 13:38:19Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $ (last)
-# $Date: 2020-01-19 15:42:51 +0800 (週日, 19 一月 2020) $
-# $Revision: 11877 $
+# $Author: Lavender $ (last)
+# $Date: 2020-02-05 22:38:19 +0900 (週三, 05 二月 2020) $
+# $Revision: 11904 $
 
 import os
 import sys
@@ -88,6 +88,7 @@ def attachSettings(settingsDict):
     # Django plugins.
     ADDING_INSTALLED_APPS = [
         'djangocms_history',
+        'djangocms_forms',
         'djangocms_file',
         'djangocms_picture',
         'Zephyrus.boilerplate',
@@ -105,11 +106,6 @@ def attachSettings(settingsDict):
         'Zephyrus.map',
     ]
     
-    if DJANGO_VERSION <= 20000: # 2.0.0
-       ADDING_INSTALLED_APPS += [
-            'djangocms_forms',
-       ]
-
     if ZEPHYRUS_BLOG_ENABLE:
         ADDING_INSTALLED_APPS += [
             'aldryn_apphooks_config',
