@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11720 2019-09-23 06:12:17Z Lavender $
+# $Id: models.py 11928 2020-02-17 04:02:19Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2019-09-23 14:12:17 +0800 (週一, 23 九月 2019) $
-# $Revision: 11720 $
+# $Author: Trista $
+# $Date: 2020-02-17 13:02:19 +0900 (週一, 17 二月 2020) $
+# $Revision: 11928 $
 
 from functools import wraps
 from django import forms
@@ -25,9 +25,14 @@ from aldryn_categories.models import Category
 from aldryn_newsblog.models import Article
 from aldryn_newsblog import models as newsblogModels
 from taggit.models import Tag
+from djangocms_forms.models import FormDefinition
+from filer.models.filemodels import File
 
+from Iuppiter.DjangoUtil import DJANGO_VERSION
 from Zephyrus.blog_extension import settings as _settings
 
+
+
 METHODS = [
     ('or',  _('OR')),
     ('and',  _('AND')),
@@ -93,7 +98,7 @@ class DatePluginConfig(CMSPlugin):
 # django == 1.11
 from django import VERSION
 
-if VERSION[0] == 1 and VERSION[1] == 11:
+if DJANGO_VERSION >= 11100: # 1.11
     def formfieldDecorator(f):
         @wraps(f)
         def wrapper(*args, **kwds):
@@ -181,3 +186,12 @@ utilities.get_plugin_index_data = get_plugin_index_data
 newsblogModels.get_plugin_index_data = get_plugin_index_data
 
 
+class Action(FormDefinition):
+    file = models.ForeignKey(File)
+
+class ActionRecord(models.Model):
+    action = models.ForeignKey(Action)
+    token = models.CharField(max_length=80)
+    email = models.CharField(max_length=500)
+    count = models.IntegerField(default=0)
+    url = models.CharField(max_length=500)
