@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 11388 2019-03-20 08:36:54Z Lavender $
+# $Id: urls.py 11928 2020-02-17 04:02:19Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and 
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2019-03-20 16:36:54 +0800 (週三, 20 三月 2019) $
-# $Revision: 11388 $ 
+# $Author: Trista $
+# $Date: 2020-02-17 13:02:19 +0900 (週一, 17 二月 2020) $
+# $Revision: 11928 $ 
 
 from django.conf.urls import url
 
@@ -25,4 +25,5 @@ urlpatterns = [
     url(r'^email$', views.EmailView.as_view(), name='landing_email'),
     url(r'^landing_social$', views.LandingSocialView.as_view(), 
         name='landing_social'),
+    url(r'^action', views.showActionFile, name='showActionFile'),
 ]
